Toy dataset containing five omics matrices that can be used for testing purposes.
toydataA list of five matrices, one for each omics type. Each matrix contains 45 rows corresponding to patient samples. The genes and gene products are in the columns.
M mutations, binary, 20 columns
CN copy number changes, ordinal, 20 columns
T transcriptome, continuous (Gaussian), 20 columns
P proteome, continuous (Gaussian), 15 columns
PP phospho-proteome, continuous (Gaussian), 20 columns